@@ -1,5 +1,5 @@
 package QBit::Validator::Type::hash;
-$QBit::Validator::Type::hash::VERSION = '0.008';
+$QBit::Validator::Type::hash::VERSION = '0.009';
 use qbit;
 
 use base qw(QBit::Validator::Type);
@@ -10,6 +10,7 @@ my $OPTIONS = [
     {name => 'deps'},
     {name => 'fields'},
     {name => 'one_of'},
+    {name => 'any_of'},
     {name => 'extra',    required => TRUE},
 ];
 
@@ -158,4 +159,34 @@ sub one_of {
     return TRUE;
 }
 
+sub any_of {
+    my ($self, $qv, $data, $template, $option, @path_field) = @_;
+
+    throw Exception::Validator gettext('Option "%s" must be ARRAY', $option)
+      if ref($template->{$option}) ne 'ARRAY';
+
+    my $min_size = 2;
+
+    throw Exception::Validator gettext('Option "%s" have size "%s", but expected size equal or more than "%s"',
+        $option, scalar(@{$template->{$option}}), $min_size)
+      if @{$template->{$option}} < $min_size;
+
+    my @received_fields = ();
+    foreach my $field (@{$template->{$option}}) {
+        throw Exception::Validator gettext('Key "%s" do not use in option "fields"', $field)
+          unless exists($template->{'fields'}{$field});
+
+        push(@received_fields, $field) if exists($data->{$field});
+    }
+
+    unless (@received_fields) {
+        $qv->_add_error($template, gettext('Expected any keys from: %s', join(', ', @{$template->{$option}})),
+            \@path_field);
+
+        return FALSE;
+    }
+
+    return TRUE;
+}
+
 TRUE;
